"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Calendar = void 0;
var _react = _interopRequireWildcard(require("react"));
var _popup = _interopRequireDefault(require("../popup"));
var _calendaritem = _interopRequireDefault(require("../calendaritem"));
var _date = _interopRequireDefault(require("../utils/date"));
var _configprovider = require("../configprovider");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  type: 'one',
  isAutoBackFill: false,
  poppable: true,
  visible: false,
  title: '日历选择',
  defaultValue: '',
  startDate: _date.default.getDay(0),
  endDate: _date.default.getDay(365),
  showToday: true,
  startText: '开始',
  endText: '结束',
  confirmText: '确认',
  showTitle: true,
  showSubTitle: true,
  toDateAnimation: true,
  onBtn: undefined,
  onDay: undefined,
  onTopInfo: undefined,
  onBottomInfo: undefined,
  onClose: () => {},
  onChoose: param => {},
  onSelected: data => {}
};
const Calendar = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    locale
  } = (0, _configprovider.useConfig)();
  const {
    poppable,
    visible,
    type,
    isAutoBackFill,
    title,
    defaultValue,
    startDate,
    endDate,
    showToday,
    startText,
    endText,
    confirmText,
    showTitle,
    showSubTitle,
    toDateAnimation,
    onBtn,
    onDay,
    onTopInfo,
    onBottomInfo,
    onClose,
    onChoose,
    onSelected
  } = {
    ...defaultProps,
    ...props
  };
  const calendarRef = (0, _react.useRef)(null);
  const close = () => {
    onClose && onClose();
  };
  const choose = param => {
    close();
    onChoose && onChoose(param);
  };
  const closePopup = () => {
    close();
  };
  const select = param => {
    onSelected && onSelected(param);
  };
  const scrollToDate = date => {
    var _calendarRef$current;
    (_calendarRef$current = calendarRef.current) === null || _calendarRef$current === void 0 ? void 0 : _calendarRef$current.scrollToDate(date);
  };
  _react.default.useImperativeHandle(ref, () => ({
    scrollToDate
  }));
  const renderItem = () => {
    return /*#__PURE__*/_react.default.createElement(_calendaritem.default, {
      ref: calendarRef,
      type: type,
      isAutoBackFill: isAutoBackFill,
      poppable: poppable,
      title: locale.calendaritem.title || title,
      defaultValue: defaultValue,
      startDate: startDate,
      endDate: endDate,
      showToday: showToday,
      startText: startText,
      endText: endText,
      confirmText: confirmText,
      showTitle: showTitle,
      showSubTitle: showSubTitle,
      toDateAnimation: toDateAnimation,
      onBtn: onBtn,
      onDay: onDay,
      onTopInfo: onTopInfo,
      onBottomInfo: onBottomInfo,
      onChoose: choose,
      onSelected: select
    });
  };
  return poppable ? /*#__PURE__*/_react.default.createElement(_popup.default, {
    visible: visible,
    position: "bottom",
    round: true,
    duration: 0.5,
    closeable: true,
    destroyOnClose: true,
    onClickOverlay: closePopup,
    onClickCloseIcon: closePopup,
    style: {
      height: '85%'
    }
  }, renderItem()) : renderItem();
});
exports.Calendar = Calendar;
Calendar.defaultProps = defaultProps;
Calendar.displayName = 'NutCalendar';
//# sourceMappingURL=calendar.js.map