"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Checkbox = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _icon = _interopRequireDefault(require("../icon"));
var _checkboxgroup = _interopRequireDefault(require("../checkboxgroup"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _filterTextStyle = _interopRequireDefault(require("../utils/filter-text-style"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  checked: false,
  disabled: false,
  textPosition: 'right',
  iconSize: 18,
  iconName: 'check-normal',
  iconActiveName: 'checked',
  iconIndeterminateName: 'check-disabled',
  onChange: (state, label) => {},
  style: {}
};
const Checkbox = props => {
  const {
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    iconName,
    iconSize,
    label,
    textPosition,
    iconActiveName,
    checked,
    disabled,
    onChange,
    indeterminate,
    iconIndeterminateName,
    getParentVals,
    max,
    style
  } = props;
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const onPressCallback = (0, _react.useCallback)(() => {
    if (!disabled) {
      const latest = !checked;
      if (max !== undefined && latest && getParentVals().length >= max) return;
      onChange && onChange(latest, label || children);
    }
  }, [disabled, checked, max, getParentVals, onChange]);
  const wrapStyle = [styles.container, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style))];
  const textStyle = [styles.text, styles[`textPosition${textPosition}`], (0, _filterTextStyle.default)((0, _styleToObj.default)(style)), styles[`textDisabled${disabled}`]];
  const iconStyle = [styles[`icon${textPosition}`]];
  const renderText = () => {
    if (typeof children === 'string') {
      return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: textStyle
      }, children);
    }
    if (label) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: textStyle
      }, label);
    }
  };
  const renderIcon = () => {
    if (disabled) {
      // 如果是禁止的状态
      if (indeterminate) {
        return /*#__PURE__*/_react.default.createElement(_icon.default, {
          name: checked ? iconIndeterminateName : iconName,
          color: checked ? '#b1b1b1' : '#d6d6d6',
          size: iconSize,
          style: iconStyle
        });
      }
      return /*#__PURE__*/_react.default.createElement(_icon.default, {
        name: checked ? iconActiveName : iconName,
        color: checked ? '#b1b1b1' : '#d6d6d6',
        size: iconSize,
        style: iconStyle
      });
    } else {
      if (indeterminate) {
        return /*#__PURE__*/_react.default.createElement(_icon.default, {
          name: checked ? iconIndeterminateName : iconName,
          color: checked ? '#fa2c19' : '#d6d6d6',
          size: iconSize,
          style: iconStyle
        });
      }
      return /*#__PURE__*/_react.default.createElement(_icon.default, {
        name: checked ? iconActiveName : iconName,
        color: checked ? '#f50f16' : '#d6d6d6',
        size: iconSize,
        style: iconStyle
      });
    }
  };
  const renderChildren = () => {
    if (textPosition === 'left') {
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, renderText(), renderIcon());
    } else {
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, renderIcon(), renderText());
    }
  };
  if (disabled) {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: wrapStyle
    }, renderChildren());
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableHighlight, {
    underlayColor: null,
    activeOpacity: 1,
    onPress: onPressCallback
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, renderChildren()));
};
exports.Checkbox = Checkbox;
Checkbox.defaultProps = defaultProps;
Checkbox.displayName = 'NutCheckBox';
Checkbox.Group = _checkboxgroup.default;
//# sourceMappingURL=checkbox.js.map