"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.elevatorContext = exports.Elevator = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _native = require("@react-spring/native");
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const elevatorContext = /*#__PURE__*/(0, _react.createContext)({});
exports.elevatorContext = elevatorContext;
const defaultProps = {
  height: 200,
  acceptKey: 'title',
  indexList: [],
  isSticky: false,
  spaceHeight: 23,
  titleHeight: 35
};
const Elevator = props => {
  const {
    height,
    acceptKey,
    indexList,
    isSticky,
    spaceHeight,
    titleHeight,
    style,
    onClickItem,
    onClickIndex,
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const listview = (0, _react.useRef)(null);
  const listHeight = (0, _react.useRef)([]);
  const [scrollY, setScrollY] = (0, _react.useState)(0);
  const [barTop, setBarTop] = (0, _react.useState)(0);
  const [currentData, setCurrentData] = (0, _react.useState)({});
  const [currentKey, setCurrentKey] = (0, _react.useState)('');
  const [codeIndex, setCodeIndex] = (0, _react.useState)(0);
  const [scrollStart, setScrollStart] = (0, _react.useState)(false);
  const panResponder = _reactNative.PanResponder.create({
    onStartShouldSetPanResponder: () => false,
    onStartShouldSetPanResponderCapture: () => false,
    onMoveShouldSetPanResponderCapture: () => true,
    onPanResponderTerminationRequest: () => false,
    // 这个很重要，这边不放权
    onShouldBlockNativeResponder: () => false,
    onMoveShouldSetPanResponder: (evt, g) => {
      // 解决PanResponder中的onPress无作用
      // 当大于5时才进入移动事件，有的情况下需要将onStartShouldSetPanResponderCapture设为false
      if (Math.abs(g.dx) > 5 || Math.abs(g.dy) > 5) {
        return true;
      } else if (Math.abs(g.dx) <= 5 || Math.abs(g.dy) <= 5) {
        return false;
      }
      return false;
    },
    // onPanResponderGrant: (e, gesture) => {
    //   console.log('onPanResponderGrant', e.nativeEvent, gesture);
    // },
    onPanResponderMove: (e, gesture) => {
      //   const padding = theme['$elevator-list-item-bars-padding'];

      let index = Math.ceil((gesture.moveY - barTop) / spaceHeight);
      if (index >= indexList.length - 1) {
        index = indexList.length - 1;
      }
      if (index <= 0) {
        index = 0;
      }
      setCodeIndex(index);
      scrollTo(index);
      setScrollStart(true);
    },
    onPanResponderRelease: () => {
      setScrollStart(false);
    }
  });

  // 获取距离屏幕顶高度
  const getBarInfo = e => {
    const handle = (0, _reactNative.findNodeHandle)(e.target);
    _reactNative.NativeModules.UIManager.measure(handle, (x0, y0, width, height, x, py) => {
      setBarTop(py);
    });
  };
  const getItemsInfo = (e, index) => {
    const {
      height
    } = e.nativeEvent.layout;
    listHeight.current[index] = height;
  };
  const scrollTo = index => {
    if (!index && index !== 0) {
      return;
    }
    if (listview.current) {
      listview.current.scrollToIndex({
        index: index,
        animated: false
      });
    }
  };
  const handleClickItem = (key, item) => {
    onClickItem === null || onClickItem === void 0 ? void 0 : onClickItem(key, item);
    setCurrentData(item);
    setCurrentKey(key);
  };
  const handleClickIndex = (key, index) => {
    setCurrentKey(key);
    setCodeIndex(index);
    scrollTo(index);
    setScrollStart(true);
    setTimeout(() => {
      setScrollStart(false);
    }, 1000);
    onClickIndex === null || onClickIndex === void 0 ? void 0 : onClickIndex(key);
  };
  const onScroll = e => {
    setScrollY(e.nativeEvent.contentOffset.y);
    listHeight.current.reduce((top, height, index) => {
      if (scrollY > top) {
        setCodeIndex(index);
      }
      return top + height;
    }, 0);
  };
  const renderItem = _ref => {
    let {
      item,
      index
    } = _ref;
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.elevatorList__item,
      key: item[acceptKey],
      onLayout: e => getItemsInfo(e, index)
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.elevatorList__item__code, {
        height: titleHeight
      }]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: styles.elevatorList__item__codeText
    }, item[acceptKey])), item.list.map(subitem => {
      const activeText = currentData.id === subitem.id && currentKey === item[acceptKey] ? styles.elevatorList__item__nameHightcolor : {};
      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
        style: styles.elevatorList__item__name,
        key: subitem.id,
        onPress: () => handleClickItem(item[acceptKey], subitem)
      }, children ? /*#__PURE__*/_react.default.createElement(elevatorContext.Provider, {
        value: subitem
      }, children) : /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: [styles.elevatorList__item__nameText, activeText]
      }, subitem.name));
    }));
  };
  const transformBar = [{
    translateY: -(spaceHeight * indexList.length) / 2
  }] || theme['$elevator-list-item-code-current-transform'];
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.elevator, style]
  }, isSticky && scrollY > 0 ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.elevatorList__fixed
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.elevatorList__fixedTitle
  }, indexList[codeIndex][acceptKey])) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.elevatorList, {
      height
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, {
    style: styles.elevatorList__inner,
    data: indexList,
    renderItem: renderItem,
    initialNumToRender: 20,
    showsVerticalScrollIndicator: false,
    keyExtractor: (item, index) => '' + index,
    onScroll: onScroll,
    ref: listview
  })), indexList.length && scrollStart ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.elevatorCodeCurrent
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.elevatorCodeCurrentText
  }, indexList[codeIndex][acceptKey])) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.elevatorBars, {
      transform: transformBar
    }],
    onLayout: getBarInfo
  }, /*#__PURE__*/_react.default.createElement(_native.animated.View, _extends({
    style: styles.elevatorBars__inner
  }, panResponder.panHandlers), indexList.map((item, index) => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: [styles.elevatorBars__inner__item, {
        height: spaceHeight
      }, item[acceptKey] === indexList[codeIndex][acceptKey] && styles.elevatorBars__inner__itemActive],
      key: item[acceptKey],
      onPress: () => handleClickIndex(item[acceptKey], index)
    }, item[acceptKey]);
  }))));
};
exports.Elevator = Elevator;
Elevator.defaultProps = defaultProps;
Elevator.displayName = 'NutElevator';
//# sourceMappingURL=elevator.js.map