"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ImageComponent = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
var _icon = _interopRequireDefault(require("../icon"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _getBorderRadiusValue = _interopRequireDefault(require("../utils/get-border-radius-value"));
var _filterWidthHeight = _interopRequireDefault(require("../utils/filter-width-height"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const ImageComponent = _ref => {
  let {
    style,
    source,
    resizeMode = 'cover',
    width = 0,
    height = 0,
    round = false,
    radius = 0,
    showError = true,
    showLoading = true,
    slotError,
    slotLoding,
    children,
    onClick,
    onLoad,
    onError,
    ...props
  } = _ref;
  const [loading, setLoading] = (0, _react.useState)(true);
  const [isError, setIsError] = (0, _react.useState)(false);
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  (0, _react.useEffect)(() => {
    if (source) {
      setIsError(false);
      setLoading(true);
    }
  }, [source]);

  // 图片加载
  const load = () => {
    if (source) {
      setLoading(false);
      onLoad && onLoad();
    }
  };

  // 图片加载失败
  const error = () => {
    if (source) {
      setIsError(true);
      setLoading(false);
      onError && onError();
    }
  };
  const wrapStyle = [styles.container, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {})), {
    height: height,
    width: width,
    overflow: radius !== undefined && radius !== null ? 'hidden' : '',
    borderRadius: radius !== undefined && radius !== null ? radius : 0
  }, round ? {
    borderRadius: (0, _getBorderRadiusValue.default)(width)
  } : {}];
  const imageStyle = [(0, _filterWidthHeight.default)((0, _styleToObj.default)(style || {})), {
    width: width,
    height: height
  }];
  const renderContent = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: wrapStyle
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, _extends({
      style: imageStyle,
      source: source,
      resizeMode: resizeMode,
      onLoad: load,
      onError: error
    }, props)), showLoading && loading ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.loading
    }, slotLoding || children || /*#__PURE__*/_react.default.createElement(_icon.default, {
      name: "image"
    })) : null, showError && isError && !loading ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.error
    }, slotError || children || /*#__PURE__*/_react.default.createElement(_icon.default, {
      name: "image-error"
    })) : null);
  };
  if (onClick) {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableHighlight, {
      underlayColor: null,
      activeOpacity: 1,
      onPress: onClick
    }, renderContent());
  }
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, renderContent());
};
exports.ImageComponent = ImageComponent;
ImageComponent.abortPrefetch = _reactNative.Image.abortPrefetch;
ImageComponent.getSize = _reactNative.Image.getSize;
ImageComponent.prefetch = _reactNative.Image.prefetch;
ImageComponent.queryCache = _reactNative.Image.queryCache;
ImageComponent.resolveAssetSource = _reactNative.Image.resolveAssetSource;
ImageComponent.displayName = 'NutImage';
//# sourceMappingURL=image.js.map