"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Input = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _utils = require("../utils");
var _icon = _interopRequireDefault(require("../icon"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
// text-align
// onChange: 在输入时执行格式化 ; onBlur: 在失焦时执行格式化

const defaultProps = {
  ..._utils.ComponentDefaults,
  type: 'text',
  name: '',
  defaultValue: '',
  placeholder: '',
  label: '',
  labelStyle: {},
  labelWidth: 80,
  labelAlign: 'left',
  colon: false,
  inputAlign: 'left',
  center: false,
  required: false,
  disabled: false,
  readonly: false,
  error: false,
  maxlength: '9999',
  leftIcon: '',
  leftIconSize: '',
  rightIcon: '',
  rightIconSize: '',
  clearable: false,
  clearIcon: 'mask-close',
  clearSize: 14,
  border: true,
  formatTrigger: 'onChange',
  rules: [],
  rows: null,
  errorMessage: '',
  errorMessageAlign: '',
  showWordLimit: false,
  autofocus: false,
  slotButton: null,
  slotInput: null
};
const Input = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => {
  const {
    locale,
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const {
    children,
    type,
    name,
    defaultValue,
    placeholder,
    label,
    labelStyle,
    labelWidth,
    labelAlign,
    colon,
    inputAlign,
    center,
    required,
    disabled,
    readonly,
    error,
    maxlength,
    leftIcon,
    leftIconSize,
    rightIcon,
    rightIconSize,
    clearable,
    clearIcon,
    clearSize,
    border,
    formatTrigger,
    rules,
    errorMessage,
    errorMessageAlign,
    showWordLimit,
    autofocus,
    style,
    className,
    rows,
    slotButton,
    slotInput,
    onChange,
    onBlur,
    onFocus,
    onClear,
    formatter,
    keypress,
    onClickInput,
    onClickLeftIcon,
    onClickRightIcon,
    onClick,
    iconClassPrefix,
    iconFontClassName,
    ...rest
  } = {
    ...defaultProps,
    ...props
  };
  locale.placeholder = placeholder || locale.placeholder;
  const [inputValue, SetInputValue] = (0, _react.useState)('');
  const [active, SetActive] = (0, _react.useState)(false);
  const [classes, setClasses] = (0, _react.useState)({});
  const getModelValue = () => String(inputValue ?? '');
  const inputRef = (0, _react.useRef)(null);
  const state = {
    focused: false,
    validateFailed: false,
    // 校验失败
    validateMessage: '' // 校验信息
  };

  (0, _react.useLayoutEffect)(() => {
    if (defaultValue) {
      updateValue(getModelValue(), formatTrigger);
    }
  });
  (0, _react.useEffect)(() => {
    setClasses(inputClass);
    SetInputValue(defaultValue);
  }, [defaultValue]);
  (0, _react.useEffect)(() => {
    if (inputValue) {
      updateValue(getModelValue());
      resetValidation();
    }
  }, [inputValue]);
  (0, _react.useImperativeHandle)(ref, () => {
    return inputRef.current;
  });
  const inputClass = (0, _react.useCallback)(() => {
    return {
      ...(center ? styles.nutInputCenter : {}),
      ...(disabled ? styles.nutInputDisabled : {}),
      ...(required ? styles.nutInputRequired : {}),
      ...(error ? styles.nutInputError : {}),
      ...(border ? styles.nutInputBorder : {}),
      ...(slotButton || rightIcon ? styles.nutInputRightMark : {})
    };
  }, [disabled, required, error, border, slotButton, rightIcon, center]);

  // 样式状态重置
  (0, _react.useEffect)(() => {
    setClasses(inputClass);
  }, [disabled, required, error, border, slotButton, rightIcon, center]);
  const updateValue = function (value) {
    var _inputRef$current;
    let trigger = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'onChange';
    let event = arguments.length > 2 ? arguments[2] : undefined;
    let val = value;
    if (type === 'digit' || type === 'tel') {
      val = (0, _utils.formatNumber)(val, false, false);
    }
    if (type === 'number') {
      val = (0, _utils.formatNumber)(val, true, true);
    }
    if (type === 'tel' && !formatter) {
      const regTel = /^(13[0-9]|14[01456879]|15[0-35-9]|16[2567]|17[0-8]|18[0-9]|19[0-35-9])\d{8}$/;
      const regNumber = /[^-0-9]/g;
      val = !regTel.test(val) && val.length > 11 ? val.substring(0, 11) : val.replace(regNumber, '');
    }
    if (formatter && trigger === formatTrigger) {
      val = formatter(val);
    }
    if ((inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.value) !== val) {
      inputRef.current.value = val;
    }
    SetInputValue(val);
    onChange && onChange(val, event);
  };
  const handleFocus = event => {
    var _event$nativeEvent;
    const val = (_event$nativeEvent = event.nativeEvent) === null || _event$nativeEvent === void 0 ? void 0 : _event$nativeEvent.text;
    SetActive(true);
    onFocus && onFocus(val, event);
  };
  const handleInput = event => {
    var _event$nativeEvent2;
    let val = (_event$nativeEvent2 = event.nativeEvent) === null || _event$nativeEvent2 === void 0 ? void 0 : _event$nativeEvent2.text;
    if (maxlength && val.length > Number(maxlength)) {
      val = val.slice(0, Number(maxlength));
    }
    updateValue(val, 'onChange', event);
  };
  const handleBlur = event => {
    var _event$nativeEvent3;
    setTimeout(() => {
      SetActive(false);
    }, 200);
    let val = (_event$nativeEvent3 = event.nativeEvent) === null || _event$nativeEvent3 === void 0 ? void 0 : _event$nativeEvent3.text;
    if (maxlength && val.length > Number(maxlength)) {
      val = val.slice(0, Number(maxlength));
    }
    updateValue(getModelValue(), 'onBlur');
    onBlur && onBlur(val, event);
  };
  const handleClickInput = event => {
    onClickInput && onClickInput(event);
  };
  const handleClickLeftIcon = event => {
    onClickLeftIcon && onClickLeftIcon(event);
  };
  const handleClickRightIcon = event => {
    onClickRightIcon && onClickRightIcon(event);
  };
  const resetValidation = () => {
    if (state.validateFailed) {
      state.validateFailed = false;
      state.validateMessage = '';
    }
  };
  const inputType = type => {
    if (type === 'number') {
      return 'text';
    }
    if (type === 'digit') {
      return 'tel';
    }
    return type;
  };
  const handleClear = event => {
    updateValue('');
    onClear && onClear('', event);
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: [styles.nutInput, classes],
    onPress: e => {
      onClick && onClick(e);
    }
  }, slotInput ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, label ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.nutInputLabel, {
      width: labelWidth
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [styles.nutInputLabelString, {
      textAlign: labelAlign
    }]
  }, label, colon ? ':' : '')) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.nutInputValue
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: [styles.nutInputInner, slotButton || rightIcon ? {
      flex: 1
    } : {}],
    onPress: e => {
      handleClickInput(e);
    }
  }, slotInput))) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, leftIcon && leftIcon.length > 0 ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: styles.nutInputLeftIcon,
    onPress: e => {
      handleClickLeftIcon(e);
    }
  }, /*#__PURE__*/_react.default.createElement(_icon.default, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    name: leftIcon,
    size: leftIconSize
  })) : null, label ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !!required && /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.nutInputLabel_required
  }, "*"), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.nutInputLabel, labelStyle, {
      width: labelWidth
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [styles.nutInputLabelString, {
      textAlign: labelAlign
    }, error && styles.nutInputText_error]
  }, label, colon ? ':' : ''))) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.nutInputValue
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [slotButton || rightIcon ? styles.nutInputMainCon : {}]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: styles.nutInputInner,
    onPress: e => {
      handleClickInput(e);
    }
  }, type === 'textarea' ? /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    multiline: true,
    ref: inputRef,
    style: [styles.nutInputText, {
      textAlign: inputAlign,
      height: Number(rows) * 24
    }, disabled && styles.nutInputText_disabled, error && styles.nutInputText_error],
    maxLength: maxlength || undefined,
    placeholder: placeholder || locale.placeholder,
    placeholderTextColor: error ? theme['$input-required-color'] : '',
    editable: !readonly && !disabled,
    value: inputValue,
    autoFocus: autofocus,
    onBlur: e => {
      handleBlur(e);
    },
    onFocus: e => {
      handleFocus(e);
    },
    onChange: e => {
      handleInput(e);
    }
  }) : /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    ref: inputRef,
    style: [styles.nutInputText, {
      textAlign: inputAlign
    }, disabled && styles.nutInputText_disabled, error && styles.nutInputText_error]
    // type={inputType(type)}
    ,
    maxLength: maxlength || undefined,
    placeholder: placeholder || locale.placeholder,
    placeholderTextColor: error ? theme['$input-required-color'] : '',
    editable: !readonly && !disabled,
    value: type === 'password' ? inputValue.replace(/./g, '*') : inputValue,
    autoFocus: autofocus,
    onBlur: e => {
      handleBlur(e);
    },
    onFocus: e => {
      handleFocus(e);
    },
    onChange: e => {
      handleInput(e);
    }
  }), clearable && !readonly && active && inputValue.length > 0 ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: styles.nutInputClear,
    onPress: e => {
      handleClear(e);
    }
  }, /*#__PURE__*/_react.default.createElement(_icon.default, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    name: clearIcon,
    size: clearSize
  })) : null), rightIcon && rightIcon.length > 0 ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: styles.nutInputRightIcon,
    onPress: e => {
      handleClickRightIcon(e);
    }
  }, /*#__PURE__*/_react.default.createElement(_icon.default, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    name: rightIcon,
    size: rightIconSize
  })) : null, slotButton ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.nutInputButton
  }, slotButton) : null, showWordLimit && maxlength ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.nutInputWordLimit
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.nutInputWordNum
  }, inputValue ? inputValue.length : 0), "/", maxlength) : null), errorMessage ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [styles.nutInputErrorMessage, {
      textAlign: errorMessageAlign
    }]
  }, errorMessage) : null)));
});
exports.Input = Input;
Input.defaultProps = defaultProps;
Input.displayName = 'NutInput';
//# sourceMappingURL=input.js.map