"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Pagination = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _pt = _interopRequireDefault(require("../utils/pt"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const defaultProps = {
  defaultValue: 1,
  mode: 'multi',
  prevText: '上一页',
  nextText: '下一页',
  pageCount: '',
  totalItems: '0',
  itemsPerPage: '10',
  showPageSize: '5',
  forceEllipses: false,
  className: '',
  pageNodeRender: item => {
    return item.text;
  }
};
const Pagination = props => {
  const {
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    modelValue,
    mode,
    prevText,
    nextText,
    pageCount,
    totalItems,
    itemsPerPage,
    showPageSize,
    onChange,
    updatecurrent,
    forceEllipses,
    pageNodeRender,
    defaultValue,
    className,
    ...rest
  } = props;
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const mStyles = (0, _styles.default)(theme);
  const [currentPage, setCurrent] = (0, _react.useState)(1);
  const [pages, setPages] = (0, _react.useState)([]);
  const [countRef, setCountRef] = (0, _react.useState)(Number(pageCount));

  // 计算页面的数量
  const computedCountRef = () => {
    const num = Number(pageCount) || Math.ceil(Number(totalItems) / Number(itemsPerPage));
    return Number.isNaN(num) ? 1 : Math.max(1, num);
  };

  // 生成pages数组，用来遍历
  const computedPages = (_currentPage, _countRef) => {
    if (mode === 'simple') return [];
    const items = [];
    const pageCount = _countRef || countRef; // 总的页面数量
    const pageSize = Number(showPageSize); // 展示的页面个数
    const _current = _currentPage || Number(currentPage); // 当前页
    let startPage = 1;
    let endPage = pageCount;
    const partialShow = pageCount > pageSize;
    if (partialShow) {
      // 选中的page在展示的page中间
      startPage = Math.max(_current - Math.floor(pageSize / 2), 1);
      endPage = startPage + pageSize - 1;
      if (endPage > pageCount) {
        endPage = pageCount;
        startPage = endPage - pageSize + 1;
      }
    }
    // 遍历生成数组
    for (let i = startPage; i <= endPage; i++) {
      const page = setPage(i, i, _current === i);
      items.push(page);
    }
    // 判断是否有折叠
    if (partialShow && pageSize > 0 && forceEllipses) {
      if (startPage > 1) {
        const prevPage = setPage(startPage - 1, '...');
        items.unshift(prevPage);
      }
      if (endPage < pageCount) {
        const nextPage = setPage(endPage + 1, '...');
        items.push(nextPage);
      }
    }
    return items;
  };
  // 点击选择page
  const selectPage = (curPage, isSelect) => {
    if (curPage > countRef || curPage < 1) return;
    // 是否传入modelValue
    if (!('modelValue' in props)) {
      setCurrent(Number(curPage));
      if (curPage !== currentPage) {
        setPages(computedPages(curPage));
      }
    }
    if (curPage !== currentPage) {
      updatecurrent && updatecurrent(curPage);
    }
    if (isSelect) onChange && onChange(curPage);
  };
  // set page 对象
  const setPage = (number, text, active) => {
    return {
      number,
      text,
      active
    };
  };
  (0, _react.useEffect)(() => {
    // 初始化 判断是否传入值 计算 当前页，总页数，生成子节点
    let currentValue = props.defaultValue || 1;
    if ('modelValue' in props) {
      currentValue = Number(props.modelValue);
    }
    const pageCount = computedCountRef();
    setCountRef(pageCount);
    setPages(computedPages(currentValue, pageCount));
  }, []);
  if ('modelValue' in props) {
    const current = props.modelValue ? Number(props.modelValue) : 1;
    if (current !== currentPage) {
      setCurrent(current);
      setPages(computedPages(Number(current)));
    }
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: mStyles.nut_pag_container
  }, rest), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: currentPage === 1 ? mStyles.nut_pag_predisable : mStyles.nut_pag_preable,
    onPress: e => selectPage(Number(currentPage) - 1, true)
  }, typeof prevText === 'string' ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: currentPage === 1 ? mStyles.nut_pag_predis_text : mStyles.nut_pag_pre_text
  }, prevText) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      alignItems: 'center',
      justifyContent: 'center'
    }
  }, prevText)), mode === 'multi' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: 'row'
    }
  }, pages.map((item, index) => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      key: `${index}pagination`,
      style: item.active ? mStyles.nut_pag_center_active : mStyles.nut_pag_center_disactive,
      onPress: e => !item.active ? selectPage(item.number, true) : ''
    }, pageNodeRender ? typeof pageNodeRender(item) === 'number' || typeof pageNodeRender(item) === 'string' ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: item.active ? mStyles.nut_pag_center_text : mStyles.nut_pag_center_distext
    }, pageNodeRender(item)) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        alignItems: 'center',
        justifyContent: 'center'
      }
    }, pageNodeRender(item)) : /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: item.active ? mStyles.nut_pag_center_text : mStyles.nut_pag_center_distext
    }, item.text));
  })) : null, mode === 'simple' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      marginHorizontal: (0, _pt.default)(100),
      alignItems: 'center',
      justifyContent: 'center'
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: mStyles.nut_pag_pre_text
  }, currentPage, "/", countRef)) : null, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: Number(currentPage) >= countRef ? mStyles.nut_pag_predisable : mStyles.nut_pag_preable,
    onPress: e => selectPage(Number(currentPage) + 1, true)
  }, typeof nextText === 'string' ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: Number(currentPage) >= countRef ? mStyles.nut_pag_predis_text : mStyles.nut_pag_pre_text
  }, nextText) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      alignItems: 'center',
      justifyContent: 'center'
    }
  }, nextText)));
};
exports.Pagination = Pagination;
Pagination.defaultProps = defaultProps;
Pagination.displayName = 'NutPagination';
//# sourceMappingURL=pagination.js.map