"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SearchBar = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _icon = _interopRequireDefault(require("../icon"));
var _typings = require("../utils/typings");
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  ..._typings.ComponentDefaults,
  placeholder: '',
  shape: 'square',
  disabled: false,
  maxLength: 9999,
  clearable: true,
  align: 'left',
  readonly: true,
  autoFocus: false,
  label: '',
  leftinIcon: /*#__PURE__*/_react.default.createElement(_icon.default, {
    name: "search",
    size: "12"
  })
};
const SearchBar = props => {
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const mStyles = (0, _styles.default)(theme);
  const searchRef = (0, _react.useRef)(null);
  const [value, setValue] = (0, _react.useState)(() => props.value);
  const {
    placeholder,
    shape,
    disabled,
    maxLength,
    clearable,
    align,
    readOnly,
    autoFocus,
    label,
    actionText,
    leftinIcon,
    rightinIcon,
    leftoutIcon,
    rightoutIcon,
    onChange,
    onFocus,
    onBlur,
    onClear,
    onCancel,
    onSearch,
    onClickLeftinIcon,
    onClickLeftoutIcon,
    onClickRightinIcon,
    onClickRightoutIcon,
    iconClassPrefix,
    iconFontClassName
  } = {
    ...defaultProps,
    ...props
  };
  const alignClass = `${align}`;
  const change = event => {
    const {
      text
    } = event === null || event === void 0 ? void 0 : event.nativeEvent;
    onChange && (onChange === null || onChange === void 0 ? void 0 : onChange(text, event));
    setValue(text);
  };
  const focus = event => {
    const {
      text
    } = event === null || event === void 0 ? void 0 : event.nativeEvent;
    onFocus && (onFocus === null || onFocus === void 0 ? void 0 : onFocus(text, event));
  };
  const blur = event => {
    const searchSelf = searchRef.current;
    searchSelf && searchSelf.blur();
    const {
      text
    } = event === null || event === void 0 ? void 0 : event.nativeEvent;
    onBlur && (onBlur === null || onBlur === void 0 ? void 0 : onBlur(text, event));
  };
  (0, _react.useEffect)(() => {
    setValue(props.value);
  }, [props.value]);
  (0, _react.useEffect)(() => {
    if (autoFocus) {
      const searchSelf = searchRef.current;
      searchSelf && searchSelf.focus();
    }
  }, [autoFocus]);
  const renderField = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
      ref: searchRef,
      style: {
        ...props.style,
        paddingRight: 10,
        padding: 0
      },
      value: value || '',
      placeholder: placeholder || '请输入内容',
      disabled: disabled,
      readOnly: readOnly,
      maxLength: maxLength,
      onKeyPress: onKeypress,
      onChange: e => change(e),
      onFocus: e => focus(e),
      onBlur: e => blur(e)
    });
  };
  const renderLeftinIcon = () => {
    if (!leftinIcon) return null;
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: mStyles.nut_search_left_in_marginH,
      onPress: e => clickLeftIcon('in-left', e)
    }, leftinIcon);
  };
  const renderLeftoutIcon = () => {
    if (!leftoutIcon) return null;
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: mStyles.nut_search_left_icon_marginright,
      onPress: e => clickLeftIcon('out-left', e)
    }, leftoutIcon);
  };
  const clickLeftIcon = (flag, event) => {
    if (flag === 'in-left') {
      onClickLeftinIcon && onClickLeftinIcon(value, event);
    } else {
      onClickLeftoutIcon && onClickLeftoutIcon(value, event);
    }
  };
  const renderRightinIcon = () => {
    if (!rightinIcon) return null;
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      onClick: e => clickRightIcon('in-right', e),
      style: mStyles.nut_search_icon_marginH
    }, rightinIcon);
  };
  const renderRightoutIcon = () => {
    if (!rightoutIcon) return null;
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      onPress: e => clickRightIcon('out-right', e),
      style: mStyles.nut_search_out_marginleft
    }, rightoutIcon);
  };
  const clickRightIcon = (flag, event) => {
    if (flag === 'in-left') {
      onClickRightinIcon && onClickRightinIcon(value, event);
    } else {
      onClickRightoutIcon && onClickRightoutIcon(value, event);
    }
  };
  const handleClear = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      onPress: e => clearaVal(e),
      style: mStyles.nut_search_clear_marginright
    }, /*#__PURE__*/_react.default.createElement(_icon.default, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: "circle-close",
      size: "12",
      color: "#555"
    }));
  };
  const clearaVal = event => {
    if (disabled || readOnly) {
      return;
    }
    setValue('');
    onClear && onClear(event);
  };
  const renderRightLabel = () => {
    if (actionText) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
        style: mStyles.nut_label_marginleft,
        onPress: cancel
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, actionText));
    }
    return null;
  };
  const onKeypress = e => {
    if (e.key === 'Enter') {
      const event = e.nativeEvent;
      if (typeof event.cancelable !== 'boolean' || event.cancelable) {
        event.preventDefault();
      }
      onSearch && onSearch(value);
    }
  };
  const cancel = () => {
    onCancel && onCancel();
  };
  const renderLabel = () => {
    if (label) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: mStyles.nut_label_margin
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, label));
    }
    return null;
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [{
      ...mStyles.nut_searchbar_container,
      ...props.style
    }, {
      backgroundColor: props.background ? props.background : '#fff'
    }]
  }, renderLeftoutIcon(), renderLabel(), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [{
      ...mStyles.nut_searchbar_inner,
      borderRadius: shape === 'round' ? 20 : 0
    }, {
      backgroundColor: props.inputBackground ? props.inputBackground : '#f7f7f7'
    }]
  }, renderLeftinIcon(), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flex: 1
    }
  }, renderField()), renderRightinIcon(), clearable && value ? handleClear() : null), renderRightoutIcon(), renderRightLabel());
};
exports.SearchBar = SearchBar;
SearchBar.defaultProps = defaultProps;
SearchBar.displayName = 'NutSearchBar';
//# sourceMappingURL=searchbar.js.map