"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Swipe = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _useClientRect = _interopRequireDefault(require("../utils/use-client-rect"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const defaultProps = {
  name: '',
  leftWidth: 0,
  rightWidth: 0
};
const Swipe = /*#__PURE__*/(0, _react.forwardRef)((props, instanceRef) => {
  const {
    children,
    style
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const [actionWidth, setActionWidth] = (0, _react.useState)({
    left: 0,
    right: 0
  });

  // 左边的宽度
  const leftWidth = (0, _react.useMemo)(() => props.leftWidth ? props.leftWidth : actionWidth.left, [props.leftWidth, actionWidth.left]);

  // 右边的宽度
  const rightWidth = (0, _react.useMemo)(() => props.rightWidth ? props.rightWidth : actionWidth.right, [props.rightWidth, actionWidth.right]);
  const leftRef = (0, _react.useCallback)(node => {
    if (node !== null) {
      setTimeout(() => {
        (0, _useClientRect.default)(node).then(res => {
          // setActionWidth((v) => ({ ...v, left: res.width }))
        });
      }, 500);
    }
  }, [props.leftAction]);
  const rightRef = (0, _react.useCallback)(node => {
    if (node !== null) {
      (0, _useClientRect.default)(node).then(res => {
        setActionWidth(v => ({
          ...v,
          right: res.width
        }));
      });
    }
  }, [props.rightAction]);
  const open = side => {
    var _props$onOpen;
    // const offset = side === 'left' ? leftWidth : -rightWidth
    const name = props.name;
    (_props$onOpen = props.onOpen) === null || _props$onOpen === void 0 ? void 0 : _props$onOpen.call(props, {
      name,
      position: side
    });
  };
  const close = position => {
    var _props$onClose;
    (_props$onClose = props.onClose) === null || _props$onClose === void 0 ? void 0 : _props$onClose.call(props, {
      name: props.name,
      position: position || 'left'
    });
  };
  (0, _react.useImperativeHandle)(instanceRef, () => ({
    open,
    close: () => {
      slideAnimation(0);
      close(position);
    }
  }));
  const {
    current: panX
  } = _react.default.useRef(new _reactNative.Animated.Value(0));
  const currValue = _react.default.useRef(0);
  const prevValue = _react.default.useRef(0);
  _react.default.useEffect(() => {
    const subs = panX.addListener(_ref => {
      let {
        value
      } = _ref;
      currValue.current = value;
    });
    return () => {
      panX.removeListener(subs);
    };
  }, [panX]);
  const slideAnimation = _react.default.useCallback(toValue => {
    _reactNative.Animated.spring(panX, {
      toValue,
      useNativeDriver: true
    }).start();
    prevValue.current = toValue;
  }, [panX]);
  const onPanResponderMove = (_, _ref2) => {
    let {
      dx
    } = _ref2;
    if (!prevValue.current) {
      prevValue.current = currValue.current;
    }
    const newDX = prevValue.current + dx;
    if (currValue.current > 0) {
      // 左边
      if (Math.abs(newDX) > leftWidth) return;
    } else {
      if (Math.abs(newDX) > rightWidth) return;
    }

    // if (Math.abs(newDX) > deviceWidth / 2) {
    //     return;
    // }
    panX.setValue(newDX);
  };
  let oldVal = 0;
  let position = '';
  const onPanResponderRelease = (_, _ref3) => {
    let {
      dx,
      ...obj
    } = _ref3;
    prevValue.current = currValue.current;
    if (Math.sign(dx) > 0 && !props.leftAction || Math.sign(dx) < 0 && !props.rightAction) {
      return slideAnimation(0);
    }
    const maxValue = currValue.current > 0 ? leftWidth : rightWidth;

    // if (Math.abs(currValue.current) >= deviceWidth / 3) {
    if (Math.abs(currValue.current) >= maxValue / 2) {
      // slideAnimation(currValue.current > 0 ? rightWidth : -leftWidth);
      slideAnimation(currValue.current > 0 ? leftWidth : -rightWidth);
      if (currValue.current > 0) {
        if (oldVal === leftWidth) {} else {
          oldVal = leftWidth;
          position = 'left';
          open('left');
        }
      } else {
        if (oldVal === rightWidth) {} else {
          oldVal = rightWidth;
          position = 'right';
          open('right');
        }
      }
    } else {
      slideAnimation(0);
      if (oldVal === 0) {} else if (oldVal !== 0) {
        oldVal = 0;
        close(position);
      }
    }
  };
  const {
    current: _panResponder
  } = _react.default.useRef(_reactNative.PanResponder.create({
    onMoveShouldSetPanResponderCapture: () => !props.disabled,
    onPanResponderGrant: () => false,
    onPanResponderMove,
    onPanResponderRelease
  }));
  const renderLeft = () => {
    if (props.beforeClose) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: {
          width: leftWidth,
          zIndex: 1
        },
        onTouchStart: () => {
          props.beforeClose(position);
        }
      }, props.leftAction);
    }
    if (props.onActionClick) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: {
          width: leftWidth,
          zIndex: 1
        },
        onTouchStart: e => {
          props.onActionClick(e, position);
        }
      }, props.leftAction);
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        width: leftWidth,
        zIndex: 1
      }
    }, props.leftAction);
  };
  const renderRight = () => {
    if (props.beforeClose) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: {
          width: rightWidth,
          zIndex: 1
        },
        onTouchStart: e => {
          props.beforeClose(position);
        }
      }, props.rightAction);
    }
    if (props.onActionClick) {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: {
          width: rightWidth,
          zIndex: 1
        },
        onTouchStart: e => {
          props.onActionClick(e, position);
        }
      }, props.rightAction);
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        width: rightWidth,
        zIndex: 1
      }
    }, props.rightAction);
  };
  const wrapStyle = [{
    width: '100%',
    justifyContent: 'center'
  }, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {}))];
  const childrens = _react.default.Children.toArray(children);
  const {
    length
  } = childrens;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.hidden, {
      flex: 1,
      flexDirection: 'row',
      justifyContent: 'space-between'
    }]
  }, renderLeft(), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flex: 0
    }
  }), renderRight()), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, _extends({
    style: {
      transform: [{
        translateX: panX
      }],
      zIndex: 2
    }
  }, _panResponder.panHandlers), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _reactNative.StyleSheet.flatten([{
      ..._reactNative.Platform.select({
        ios: {
          padding: 14
        },
        default: {
          padding: 14
        }
      }),
      flexDirection: 'row',
      alignItems: 'center',
      backgroundColor: '#fff'
    }])
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, null, _react.default.Children.map(childrens, (child, index) => child && [child, index !== length - 1 && /*#__PURE__*/_react.default.createElement(_reactNative.View, null)])))));
});
exports.Swipe = Swipe;
Swipe.defaultProps = defaultProps;
Swipe.displayName = 'NutSwipe';
//# sourceMappingURL=swipe.js.map