"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Toast = void 0;
var React = _interopRequireWildcard(require("react"));
var _notification = _interopRequireDefault(require("./notification"));
var _portal = _interopRequireDefault(require("../portal"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
let messageInstance = null;
const options = {
  msg: '',
  id: '',
  // 标识符，相同时共用一个实例，默认为多个实例
  style: {},
  duration: 2000,
  // 时长,duration为0则一直展示
  center: true,
  // toast是否居中展示
  type: 'text',
  title: '',
  // 标题 String
  bottom: 30,
  // center为false时生效，距离底部位置
  size: 'base',
  // 设置字体大小，默认base,可选large\small\base
  icon: null,
  // 自定义图标，支持图片链接或base64格式
  iconSize: 20,
  // 自定义图标尺寸
  textAlignCenter: true,
  // 文字是否居中显示,true为居中，false为left
  loadingRotate: true,
  // 未实现
  bgColor: 'rgba(0, 0, 0, 0.8)',
  onClose: () => {},
  cover: false,
  // 是否展示透明遮罩层
  coverColor: 'rgba(0, 0, 0, 0)',
  // 遮罩颜色设定
  closeOnClickOverlay: false // 是否点击遮罩可关闭
};

const toastKeyMap = {};
const remove = key => {
  _portal.default.remove(key);
  delete toastKeyMap[key];
};
const removeAll = () => {
  Object.keys(toastKeyMap).forEach(_key => _portal.default.remove(Number.parseInt(_key, 10)));
};
function getInstance(props, callback) {
  if (messageInstance) {
    messageInstance.destroy();
    messageInstance = null;
  }
  _notification.default.newInstance(props, notification => {
    return callback && callback(notification);
  });
}
function notice(opts) {
  function close() {
    if (messageInstance) {
      messageInstance.destroy();
      messageInstance = null;
      removeAll();
    }
  }
  const opts2 = {
    ...options,
    ...opts,
    onClose: close
  };
  getInstance(opts2, notification => {
    messageInstance = notification;
  });
  const key = _portal.default.add( /*#__PURE__*/React.createElement(_notification.default, _extends({}, opts2, {
    onAnimationEnd: () => {
      remove(key);
    }
  })));
  toastKeyMap[key] = 1;
}
const errorMsg = msg => {
  if (!msg) {
    console.warn('[NutUI Toast]: msg cannot be null');
  }
};
const Toast = {
  text(msg) {
    let option = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    errorMsg(msg);
    return notice({
      msg,
      type: 'text',
      ...option
    });
  },
  success(msg) {
    let option = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    errorMsg(msg);
    return notice({
      msg,
      icon: 'success',
      type: 'success',
      ...option
    });
  },
  fail(msg) {
    let option = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    errorMsg(msg);
    return notice({
      msg,
      icon: 'failure',
      type: 'fail',
      ...option
    });
  },
  loading(msg) {
    let option = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    errorMsg(msg);
    return notice({
      msg,
      icon: 'loading',
      type: 'loading',
      ...option
    });
  },
  warn(msg) {
    let option = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    errorMsg(msg);
    return notice({
      msg,
      icon: 'tips',
      type: 'warn',
      ...option
    });
  },
  customIcon(msg) {
    let option = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    errorMsg(msg);
    return notice({
      msg,
      ...option
    });
  },
  hide() {
    if (messageInstance) {
      // messageInstance.destroy();
      messageInstance = null;
      removeAll();
    }
  }
};
exports.Toast = Toast;
//# sourceMappingURL=toast.js.map