import React, { useRef } from 'react';
import Popup from '../popup';
import CalendarItem from '../calendaritem';
import Utils from '../utils/date';
import { useConfig } from '../configprovider';
const defaultProps = {
  type: 'one',
  isAutoBackFill: false,
  poppable: true,
  visible: false,
  title: '日历选择',
  defaultValue: '',
  startDate: Utils.getDay(0),
  endDate: Utils.getDay(365),
  showToday: true,
  startText: '开始',
  endText: '结束',
  confirmText: '确认',
  showTitle: true,
  showSubTitle: true,
  toDateAnimation: true,
  onBtn: undefined,
  onDay: undefined,
  onTopInfo: undefined,
  onBottomInfo: undefined,
  onClose: () => {},
  onChoose: param => {},
  onSelected: data => {}
};
export const Calendar = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    locale
  } = useConfig();
  const {
    poppable,
    visible,
    type,
    isAutoBackFill,
    title,
    defaultValue,
    startDate,
    endDate,
    showToday,
    startText,
    endText,
    confirmText,
    showTitle,
    showSubTitle,
    toDateAnimation,
    onBtn,
    onDay,
    onTopInfo,
    onBottomInfo,
    onClose,
    onChoose,
    onSelected
  } = {
    ...defaultProps,
    ...props
  };
  const calendarRef = useRef(null);
  const close = () => {
    onClose && onClose();
  };
  const choose = param => {
    close();
    onChoose && onChoose(param);
  };
  const closePopup = () => {
    close();
  };
  const select = param => {
    onSelected && onSelected(param);
  };
  const scrollToDate = date => {
    var _calendarRef$current;
    (_calendarRef$current = calendarRef.current) === null || _calendarRef$current === void 0 ? void 0 : _calendarRef$current.scrollToDate(date);
  };
  React.useImperativeHandle(ref, () => ({
    scrollToDate
  }));
  const renderItem = () => {
    return /*#__PURE__*/React.createElement(CalendarItem, {
      ref: calendarRef,
      type: type,
      isAutoBackFill: isAutoBackFill,
      poppable: poppable,
      title: locale.calendaritem.title || title,
      defaultValue: defaultValue,
      startDate: startDate,
      endDate: endDate,
      showToday: showToday,
      startText: startText,
      endText: endText,
      confirmText: confirmText,
      showTitle: showTitle,
      showSubTitle: showSubTitle,
      toDateAnimation: toDateAnimation,
      onBtn: onBtn,
      onDay: onDay,
      onTopInfo: onTopInfo,
      onBottomInfo: onBottomInfo,
      onChoose: choose,
      onSelected: select
    });
  };
  return poppable ? /*#__PURE__*/React.createElement(Popup, {
    visible: visible,
    position: "bottom",
    round: true,
    duration: 0.5,
    closeable: true,
    destroyOnClose: true,
    onClickOverlay: closePopup,
    onClickCloseIcon: closePopup,
    style: {
      height: '85%'
    }
  }, renderItem()) : renderItem();
});
Calendar.defaultProps = defaultProps;
Calendar.displayName = 'NutCalendar';
//# sourceMappingURL=calendar.js.map