import React, { useEffect, useImperativeHandle, useState } from 'react';
import { View } from 'react-native';
import toObj from '../utils/style-to-obj';
import checkboxGroupStyle from './styles';
const defaultProps = {
  disabled: false,
  checkedValue: [],
  max: undefined,
  onChange: value => {},
  style: {}
};
export const CheckboxGroup = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    disabled,
    onChange,
    checkedValue,
    max,
    style
  } = props;
  const styles = checkboxGroupStyle();
  const [innerDisabled, setInnerDisabled] = useState(disabled);
  const [innerValue, setInnerValue] = useState(checkedValue);
  useImperativeHandle(ref, () => ({
    toggleAll(state) {
      if (state === false) {
        setInnerValue([]);
      } else {
        const childrenLabel = [];
        React.Children.map(children, child => {
          const childProps = child.props;
          childrenLabel.push(childProps.label || child.children);
        });
        setInnerValue(childrenLabel);
      }
    },
    toggleReverse() {
      const childrenLabel = [];
      React.Children.map(children, child => {
        const childProps = child.props;
        childrenLabel.push(childProps.label || child.children);
      });
      const reverse = childrenLabel.filter(c => (innerValue === null || innerValue === void 0 ? void 0 : innerValue.findIndex(v => v === c)) === -1);
      setInnerValue(reverse);
    }
  }));
  useEffect(() => {
    setInnerDisabled(disabled);
    setInnerValue(checkedValue);
  }, [disabled, checkedValue]);
  function handleChildChange(state, label) {
    if (max !== undefined && innerValue && innerValue.length > max) return;
    if (innerValue) {
      let clippedValue = [];
      if (state) {
        clippedValue = [...innerValue, label];
      } else {
        innerValue === null || innerValue === void 0 ? void 0 : innerValue.splice(innerValue === null || innerValue === void 0 ? void 0 : innerValue.indexOf(label), 1);
        clippedValue = [...innerValue];
      }
      setInnerValue(clippedValue);
      onChange && onChange(clippedValue);
    }
  }
  function validateChildChecked(child) {
    if (!innerValue) return false;
    return (innerValue === null || innerValue === void 0 ? void 0 : innerValue.indexOf(child.props.label || child.children)) > -1;
  }
  function getParentVals() {
    return innerValue;
  }
  function cloneChildren() {
    return React.Children.map(children, child => {
      const childChecked = validateChildChecked(child);
      if (child.type.displayName !== 'NutCheckBox') {
        return /*#__PURE__*/React.cloneElement(child);
      }
      return /*#__PURE__*/React.cloneElement(child, {
        disabled: innerDisabled,
        checked: childChecked,
        onChange: handleChildChange,
        getParentVals,
        max
      });
    });
  }
  const wrapStyle = [styles.container, toObj(style || {})];
  return /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, cloneChildren());
});
CheckboxGroup.defaultProps = defaultProps;
CheckboxGroup.displayName = 'NutCheckboxGroup';
//# sourceMappingURL=checkboxgroup.js.map