import React, { useEffect, useState, memo } from 'react';
import { View } from 'react-native';
import pt from '../utils/pt';
const defaultProps = {
  style: {},
  activeName: ['0'],
  accordion: false,
  icon: '',
  iconSize: pt(32),
  iconColor: '',
  rotate: 180
};
function areEqual(prevProps, nextProps) {
  return prevProps.children === nextProps.children && JSON.stringify(prevProps.activeName) === JSON.stringify(nextProps.activeName);
}
export const Collapse = /*#__PURE__*/memo(props => {
  const {
    style,
    children,
    activeName,
    accordion,
    icon,
    rotate,
    iconSize,
    iconColor,
    onChange
  } = {
    ...defaultProps,
    ...props
  };
  const childrenDom = React.Children.toArray(children);
  const [defaultOpenIndex, setDefaultOpenIndex] = useState([]);
  const handleActiveName = () => {
    let activeArr = [];
    if (!Array.isArray(activeName)) {
      activeArr.push(activeName.toString());
    } else {
      // 数组
      if (accordion && activeName.length > 1) {
        console.warn('手风琴模式不支持传递多个打开页签');
      }
      const activeNameStr = activeName.map(item => {
        return item.toString();
      });
      activeArr = [...activeNameStr];
    }
    return activeArr;
  };
  useEffect(() => {
    const activeArr = handleActiveName();
    setDefaultOpenIndex(activeArr);
  }, [activeName]);
  const onToggle = (isOpen, name) => {
    let newOpenIndex = [...defaultOpenIndex];
    if (isOpen) {
      // 当前状态为true，则变为false,闭合
      const removeIndex = newOpenIndex.findIndex(value => {
        return value === name;
      });
      newOpenIndex.splice(removeIndex, 1);
    } else {
      // 当前状态为false，变为true，展开
      if (accordion) {
        newOpenIndex = [name];
      } else {
        newOpenIndex.push(name);
      }
    }
    setDefaultOpenIndex(newOpenIndex);
    onChange === null || onChange === void 0 ? void 0 : onChange(!isOpen, name);
  };
  return /*#__PURE__*/React.createElement(View, {
    style: [style, {
      width: '100%'
    }]
  }, childrenDom.map(item => {
    return /*#__PURE__*/React.cloneElement(item, {
      isOpen: defaultOpenIndex.includes(item.props.name),
      onToggle: (isOpen, name) => onToggle(isOpen, name),
      icon,
      rotate,
      iconSize,
      iconColor,
      childnull: !!item.props.children
    });
  }));
}, areEqual);
Collapse.defaultProps = defaultProps;
Collapse.displayName = 'NutCollapse';
//# sourceMappingURL=collapse.js.map