import React from 'react';
import { View, StyleSheet } from 'react-native';
import Button from '../button';
import BaseModal from './base-modal';
import Content from './content';
import alert from './alert';
import pt from '../utils/pt';
class Dialog extends React.Component {
  static defaultProps = {
    okText: '确认',
    cancelText: '取消',
    mask: true,
    closeOnClickOverlay: true,
    noFooter: false,
    noOkBtn: false,
    noCancelBtn: false,
    okBtnDisabled: false,
    cancelAutoClose: true,
    textAlign: 'center',
    footerDirection: 'horizontal',
    lockScroll: false
  };
  render() {
    const {
      visible,
      footer,
      title,
      noFooter,
      noOkBtn,
      noCancelBtn,
      lockScroll,
      okBtnDisabled,
      cancelAutoClose,
      okText,
      cancelText,
      onClosed,
      onCancel,
      footerDirection,
      onOk,
      content,
      textAlign,
      children
    } = this.props;

    // 渲染底部
    const renderFooter = function () {
      if (footer === null || noFooter) return '';
      const handleCancel = e => {
        if (!cancelAutoClose) return;
        onClosed === null || onClosed === void 0 ? void 0 : onClosed();
        onCancel === null || onCancel === void 0 ? void 0 : onCancel();
      };
      const handleOk = e => {
        onClosed === null || onClosed === void 0 ? void 0 : onClosed();
        onOk === null || onOk === void 0 ? void 0 : onOk(e);
      };
      const cancelStyle = [styles.cancelWrap, footerDirection === 'vertical' ? {
        borderWidth: 0,
        marginRight: 0,
        marginTop: pt(40)
      } : {}];
      const okStyle = [styles.okWrap, footerDirection === 'vertical' ? {
        marginTop: pt(20),
        width: '100%'
      } : {}];
      const footerContent = footer || /*#__PURE__*/React.createElement(React.Fragment, null, !noCancelBtn && /*#__PURE__*/React.createElement(Button, {
        style: cancelStyle,
        size: "small",
        plain: true,
        type: "primary",
        onPress: handleCancel
      }, cancelText), !noOkBtn && /*#__PURE__*/React.createElement(Button, {
        size: "small",
        style: okStyle,
        type: "primary",
        disabled: okBtnDisabled,
        onPress: handleOk
      }, okText));
      return footerContent;
    };
    return /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(BaseModal, {
      visible: visible,
      animationType: 'fade',
      wrapStyle: styles.center
      // onRequestClose={onRequestClose}
      // onClose={onClose}
    }, /*#__PURE__*/React.createElement(Content, {
      visible: visible,
      title: title,
      footer: renderFooter(),
      textAlign: textAlign,
      footerDirection: footerDirection,
      content: content
    }, children)));
  }
}
Dialog.alert = alert;
export default Dialog;
const styles = StyleSheet.create({
  cancelWrap: {
    marginRight: pt(40),
    width: pt(208),
    height: pt(60)
  },
  okWrap: {
    width: pt(208),
    height: pt(60)
  },
  center: {
    justifyContent: 'center',
    alignItems: 'center'
  }
});
//# sourceMappingURL=dialog.js.map