import React from 'react';
import { View, TouchableOpacity } from 'react-native';
const defaultProps = {
  type: '',
  justify: 'start',
  align: 'flex-start',
  wrap: 'nowrap',
  gutter: '0',
  onClick: () => {}
};
export const Row = props => {
  const {
    children,
    type,
    justify,
    align,
    wrap,
    gutter,
    onClick
  } = {
    ...defaultProps,
    ...props
  };
  const getContainerStyle = () => {
    let styles = {};
    switch (justify) {
      case 'start':
        styles = {
          justifyContent: 'flex-start'
        };
        break;
      case 'end':
        styles = {
          justifyContent: 'flex-end'
        };
        break;
      case 'center':
      case 'space-around':
      case 'space-between':
      case 'space-evenly':
        styles = {
          justifyContent: justify
        };
        break;
      default:
        styles = {
          justifyContent: justify
        };
        break;
    }
    return styles;
  };
  const getWrapStyle = () => {
    let styles = {};
    switch (wrap) {
      case 'nowrap':
      case 'wrap':
        styles = {
          flexWrap: wrap
        };
        break;
      default:
        styles = {
          flexWrap: 'nowrap'
        };
        break;
    }
    return styles;
  };
  let cloneChildren = children;
  if (Array.isArray(cloneChildren) || Object.prototype.toString.call(cloneChildren) === '[object Object]') {
    if (Array.isArray(cloneChildren)) {
      if (gutter) {
        let returnView = [];
        for (let i = 0; i < cloneChildren.length; i++) {
          if (i === cloneChildren.length - 1) {
            returnView.push( /*#__PURE__*/React.cloneElement(cloneChildren[i], {
              key: i,
              gutter: gutter
            }));
          } else {
            returnView.push( /*#__PURE__*/React.cloneElement(cloneChildren[i], {
              key: i,
              gutter: gutter
            }));
            returnView.push( /*#__PURE__*/React.createElement(View, {
              key: 'gutter' + i,
              style: {
                width: parseInt(gutter)
              }
            }));
          }
        }
        if (wrap === 'reverse') {
          cloneChildren = returnView.reverse();
        } else {
          cloneChildren = returnView;
        }
      } else {
        cloneChildren = cloneChildren.map((o, i) => {
          return /*#__PURE__*/React.cloneElement(o, {
            key: i,
            gutter: gutter
          });
        });
      }
    } else {
      cloneChildren = /*#__PURE__*/React.cloneElement(cloneChildren, {
        gutter: gutter
      });
    }
  }
  if (type === 'flex') {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: [{
        width: '100%',
        flexDirection: 'row',
        alignItems: align
      }, getContainerStyle(), getWrapStyle()],
      onPress: e => {
        onClick && onClick(e, 'row');
      }
    }, cloneChildren);
  } else {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: [{
        width: '100%',
        flexDirection: 'row'
      }, getWrapStyle()],
      onPress: e => {
        onClick && onClick(e, 'row');
      }
    }, cloneChildren);
  }
};
Row.defaultProps = defaultProps;
Row.displayName = 'NutRow';
//# sourceMappingURL=row.js.map