import React, { useRef, useEffect } from 'react';
import { View, Animated, Platform } from 'react-native';
import Avatar from '../avatar';
import * as LinearGradient from 'react-native-linear-gradient';
import fConStyle from '../utils/filter-container-style';
import toObj from '../utils/style-to-obj';
import pt from '../utils/pt';
import { useConfig } from '../configprovider';
import skeletonStyles from './styles';
const defaultProps = {
  width: 100,
  height: 100,
  row: 1,
  animated: false,
  title: false,
  avatar: false,
  round: false,
  avatarSize: 50,
  loading: false,
  avatarShape: 'round'
};
export const Skeleton = props => {
  const {
    width,
    height,
    animated,
    row,
    title,
    avatar,
    avatarSize,
    style,
    round,
    loading,
    children,
    avatarShape
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const styles = skeletonStyles(theme);
  const animationRef = useRef(new Animated.Value(0));
  const animationLoop = useRef();
  const [layoutWidth, setLayoutWidth] = React.useState(0);
  const repeatLines = num => {
    return Array.from({
      length: num
    }, (v, i) => i);
  };
  useEffect(() => {
    animationLoop.current = Animated.timing(animationRef.current, {
      toValue: 2,
      delay: 400,
      duration: 1500,
      useNativeDriver: !!Platform.select({
        web: false,
        native: true
      })
    });
    animationRef.current.setValue(0);
    Animated.loop(animationLoop.current).start();
  }, []);
  const getStyle = () => {
    if (avatarSize) {
      return {
        width: avatarSize,
        height: avatarSize
      };
    }
    return {
      width: 50,
      height: 50
    };
  };
  const wrapStyle = [styles.container, fConStyle(toObj(style || {}))];
  const blockStyle = [styles.blockStyle, round ? styles.blockRoundStyle : {}, {
    width,
    height
  }];
  const avatarStyle = [styles.avatarStyle, getStyle()];
  const LinearGradientModuleRef = LinearGradient;
  const LinearGradientComponent = LinearGradientModuleRef.LinearGradient || LinearGradientModuleRef.default;
  return /*#__PURE__*/React.createElement(React.Fragment, null, loading ? /*#__PURE__*/React.createElement(View, null, children) : /*#__PURE__*/React.createElement(View, {
    style: wrapStyle,
    onLayout: _ref => {
      let {
        nativeEvent
      } = _ref;
      setLayoutWidth(nativeEvent.layout.width);
    }
  }, animated ? /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.skeletonAnimation, {
      height: height * row,
      width: width / 4
    }, {
      transform: [{
        translateX: animationRef.current.interpolate({
          inputRange: [0, 1],
          outputRange: [-width / 4, width]
        })
      }]
    }]
  }, /*#__PURE__*/React.createElement(LinearGradientComponent, {
    style: {
      height: height * row + (row > 1 ? row * pt(20) : 0) + (title ? pt(30) : 0)
    },
    colors: ['rgba(255,255,255,0.3)', 'rgba(255,255,255,0.5)', 'rgba(255,255,255,0.3)'],
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    }
  })) : null, /*#__PURE__*/React.createElement(View, {
    style: styles.nutSkeletonContent
  }, avatar && /*#__PURE__*/React.createElement(Avatar, {
    style: avatarStyle,
    bgColor: "rgb(239, 239, 239)",
    shape: avatarShape
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.skeletonContentLine
  }, title && /*#__PURE__*/React.createElement(View, {
    style: styles.skeletonTitle
  }), repeatLines(row).map((item, index) => {
    return /*#__PURE__*/React.createElement(View, {
      style: blockStyle,
      key: +index
    });
  })))));
};
Skeleton.defaultProps = defaultProps;
Skeleton.displayName = 'NutSkeleton';
//# sourceMappingURL=skeleton.js.map