function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { forwardRef, useState, useMemo, useCallback, useImperativeHandle } from 'react';
import { View, PanResponder, StyleSheet, Animated, Platform } from 'react-native';
import fConStyle from '../utils/filter-container-style';
import toObj from '../utils/style-to-obj';
import getRect from '../utils/use-client-rect';
import { useConfig } from '../configprovider';
import swipeStyles from './styles';
const defaultProps = {
  name: '',
  leftWidth: 0,
  rightWidth: 0
};
export const Swipe = /*#__PURE__*/forwardRef((props, instanceRef) => {
  const {
    children,
    style
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const styles = swipeStyles(theme);
  const [actionWidth, setActionWidth] = useState({
    left: 0,
    right: 0
  });

  // 左边的宽度
  const leftWidth = useMemo(() => props.leftWidth ? props.leftWidth : actionWidth.left, [props.leftWidth, actionWidth.left]);

  // 右边的宽度
  const rightWidth = useMemo(() => props.rightWidth ? props.rightWidth : actionWidth.right, [props.rightWidth, actionWidth.right]);
  const leftRef = useCallback(node => {
    if (node !== null) {
      setTimeout(() => {
        getRect(node).then(res => {
          // setActionWidth((v) => ({ ...v, left: res.width }))
        });
      }, 500);
    }
  }, [props.leftAction]);
  const rightRef = useCallback(node => {
    if (node !== null) {
      getRect(node).then(res => {
        setActionWidth(v => ({
          ...v,
          right: res.width
        }));
      });
    }
  }, [props.rightAction]);
  const open = side => {
    var _props$onOpen;
    // const offset = side === 'left' ? leftWidth : -rightWidth
    const name = props.name;
    (_props$onOpen = props.onOpen) === null || _props$onOpen === void 0 ? void 0 : _props$onOpen.call(props, {
      name,
      position: side
    });
  };
  const close = position => {
    var _props$onClose;
    (_props$onClose = props.onClose) === null || _props$onClose === void 0 ? void 0 : _props$onClose.call(props, {
      name: props.name,
      position: position || 'left'
    });
  };
  useImperativeHandle(instanceRef, () => ({
    open,
    close: () => {
      slideAnimation(0);
      close(position);
    }
  }));
  const {
    current: panX
  } = React.useRef(new Animated.Value(0));
  const currValue = React.useRef(0);
  const prevValue = React.useRef(0);
  React.useEffect(() => {
    const subs = panX.addListener(_ref => {
      let {
        value
      } = _ref;
      currValue.current = value;
    });
    return () => {
      panX.removeListener(subs);
    };
  }, [panX]);
  const slideAnimation = React.useCallback(toValue => {
    Animated.spring(panX, {
      toValue,
      useNativeDriver: true
    }).start();
    prevValue.current = toValue;
  }, [panX]);
  const onPanResponderMove = (_, _ref2) => {
    let {
      dx
    } = _ref2;
    if (!prevValue.current) {
      prevValue.current = currValue.current;
    }
    const newDX = prevValue.current + dx;
    if (currValue.current > 0) {
      // 左边
      if (Math.abs(newDX) > leftWidth) return;
    } else {
      if (Math.abs(newDX) > rightWidth) return;
    }

    // if (Math.abs(newDX) > deviceWidth / 2) {
    //     return;
    // }
    panX.setValue(newDX);
  };
  let oldVal = 0;
  let position = '';
  const onPanResponderRelease = (_, _ref3) => {
    let {
      dx,
      ...obj
    } = _ref3;
    prevValue.current = currValue.current;
    if (Math.sign(dx) > 0 && !props.leftAction || Math.sign(dx) < 0 && !props.rightAction) {
      return slideAnimation(0);
    }
    const maxValue = currValue.current > 0 ? leftWidth : rightWidth;

    // if (Math.abs(currValue.current) >= deviceWidth / 3) {
    if (Math.abs(currValue.current) >= maxValue / 2) {
      // slideAnimation(currValue.current > 0 ? rightWidth : -leftWidth);
      slideAnimation(currValue.current > 0 ? leftWidth : -rightWidth);
      if (currValue.current > 0) {
        if (oldVal === leftWidth) {} else {
          oldVal = leftWidth;
          position = 'left';
          open('left');
        }
      } else {
        if (oldVal === rightWidth) {} else {
          oldVal = rightWidth;
          position = 'right';
          open('right');
        }
      }
    } else {
      slideAnimation(0);
      if (oldVal === 0) {} else if (oldVal !== 0) {
        oldVal = 0;
        close(position);
      }
    }
  };
  const {
    current: _panResponder
  } = React.useRef(PanResponder.create({
    onMoveShouldSetPanResponderCapture: () => !props.disabled,
    onPanResponderGrant: () => false,
    onPanResponderMove,
    onPanResponderRelease
  }));
  const renderLeft = () => {
    if (props.beforeClose) {
      return /*#__PURE__*/React.createElement(View, {
        style: {
          width: leftWidth,
          zIndex: 1
        },
        onTouchStart: () => {
          props.beforeClose(position);
        }
      }, props.leftAction);
    }
    if (props.onActionClick) {
      return /*#__PURE__*/React.createElement(View, {
        style: {
          width: leftWidth,
          zIndex: 1
        },
        onTouchStart: e => {
          props.onActionClick(e, position);
        }
      }, props.leftAction);
    }
    return /*#__PURE__*/React.createElement(View, {
      style: {
        width: leftWidth,
        zIndex: 1
      }
    }, props.leftAction);
  };
  const renderRight = () => {
    if (props.beforeClose) {
      return /*#__PURE__*/React.createElement(View, {
        style: {
          width: rightWidth,
          zIndex: 1
        },
        onTouchStart: e => {
          props.beforeClose(position);
        }
      }, props.rightAction);
    }
    if (props.onActionClick) {
      return /*#__PURE__*/React.createElement(View, {
        style: {
          width: rightWidth,
          zIndex: 1
        },
        onTouchStart: e => {
          props.onActionClick(e, position);
        }
      }, props.rightAction);
    }
    return /*#__PURE__*/React.createElement(View, {
      style: {
        width: rightWidth,
        zIndex: 1
      }
    }, props.rightAction);
  };
  const wrapStyle = [{
    width: '100%',
    justifyContent: 'center'
  }, fConStyle(toObj(style || {}))];
  const childrens = React.Children.toArray(children);
  const {
    length
  } = childrens;
  return /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.hidden, {
      flex: 1,
      flexDirection: 'row',
      justifyContent: 'space-between'
    }]
  }, renderLeft(), /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 0
    }
  }), renderRight()), /*#__PURE__*/React.createElement(Animated.View, _extends({
    style: {
      transform: [{
        translateX: panX
      }],
      zIndex: 2
    }
  }, _panResponder.panHandlers), /*#__PURE__*/React.createElement(View, {
    style: StyleSheet.flatten([{
      ...Platform.select({
        ios: {
          padding: 14
        },
        default: {
          padding: 14
        }
      }),
      flexDirection: 'row',
      alignItems: 'center',
      backgroundColor: '#fff'
    }])
  }, /*#__PURE__*/React.createElement(View, null, React.Children.map(childrens, (child, index) => child && [child, index !== length - 1 && /*#__PURE__*/React.createElement(View, null)])))));
});
Swipe.defaultProps = defaultProps;
Swipe.displayName = 'NutSwipe';
//# sourceMappingURL=swipe.js.map